@@ -329,7 +329,6 @@ def _execute_multiblob_acl_change(
     user_email_list: List[str],
     blob_list: List[storage.Blob],
     callback_fn: Callable[[storage.acl._ACLEntity], None],
-    is_group: bool = False,
 ) -> None:
     """
     Spools out each blob and each user with saving the blob.
@@ -337,8 +336,6 @@ def _execute_multiblob_acl_change(
         See see https://googleapis.dev/python/storage/latest/acl.html
     After processing all of the users for each blob, blob.acl.save() is called.
 
-    If is_group, uses blob.acl.group instead of blob.acl.user
-
     Parameters
     ----------
     user_email_list : List[str]
@@ -349,12 +346,8 @@ def _execute_multiblob_acl_change(
     """
     for blob in blob_list:
         for user_email in user_email_list:
-            if is_group:
-                blob_group = blob.acl.group(user_email)
-                callback_fn(blob_group)
-            else:
-                blob_user = blob.acl.user(user_email)
-                callback_fn(blob_user)
+            blob_user = blob.acl.user(user_email)
+            callback_fn(blob_user)
 
         blob.acl.save()
 
@@ -382,11 +375,9 @@ def get_blob_names(
 def grant_download_access_to_blob_names(
     user_email_list: List[str],
     blob_name_list: List[str],
-    is_group: bool = False,
 ) -> None:
     """
     Using ACL, grant download access to all blobs given to the user(s) given.
-    If is_group, uses blob.acl.group instead of blob.acl.user
     """
     bucket = _get_bucket(GOOGLE_ACL_DATA_BUCKET)
     blob_list = [bucket.get_blob(name) for name in blob_name_list]
@@ -398,7 +389,6 @@ def grant_download_access_to_blob_names(
         user_email_list=user_email_list,
         blob_list=blob_list,
         callback_fn=lambda obj: obj.grant_read(),
-        is_group=is_group,
     )
 
 
@@ -441,7 +431,6 @@ def grant_download_access(
 def revoke_download_access_from_blob_names(
     user_email_list: List[str],
     blob_name_list: List[str],
-    is_group: bool = False,
 ) -> None:
     """
     Using ACL, grant download access to all blobs given to the users given.
@@ -458,7 +447,6 @@ def revoke_download_access_from_blob_names(
         blob_list=blob_list,
         callback_fn=revoke,
         user_email_list=user_email_list,
-        is_group=is_group,
     )
 
 
